@@ -15,12 +15,12 @@ pgFormatter::CLI - Implementation of command line program to format SQL queries.
 
 =head1 VERSION
 
-Version 4.2
+Version 4.3
 
 =cut
 
 # Version of pgFormatter
-our $VERSION = '4.2';
+our $VERSION = '4.3';
 
 use autodie;
 use pgFormatter::Beautify;
@@ -100,6 +100,8 @@ sub beautify {
     $args{ 'wrap_after' }   = $self->{ 'cfg' }->{ 'wrap-after' };
     $args{ 'space' }        = $self->{ 'cfg' }->{ 'space' };
     $args{ 'no_grouping' }  = $self->{ 'cfg' }->{ 'nogrouping' };
+    $args{ 'numbering' }    = $self->{ 'cfg' }->{ 'numbering' };
+    $args{ 'redshift' }     = $self->{ 'cfg' }->{ 'redshift' };
 
     if ($self->{ 'query' } && ($args{ 'maxlength' } && length($self->{ 'query' }) > $args{ 'maxlength' })) {
         $self->{ 'query' } = substr($self->{ 'query' }, 0, $args{ 'maxlength' })
@@ -203,8 +205,10 @@ Options:
     -m | --maxlength SIZE : maximum length of a query, it will be cutted above
                             the given size. Default: no truncate.
     -n | --nocomment      : remove any comment from SQL code.
+    -N | --numbering      : statement numbering as a comment before each query.
     -o | --output file    : define the filename for the output. Default: stdout.
     -p | --placeholder re : set regex to find code that must not be changed.
+    -r | --redshift       : add RedShift keyworks to the list of SQL keyworks.
     -s | --spaces size    : change space indent, default 4 spaces.
     -S | --separator STR  : dynamic code separator, default to single quote.
     -t | --format-type    : try another formatting type for some statements.
@@ -279,8 +283,10 @@ sub get_command_line_args {
         'help|h!',
         'maxlength|m=i',
         'nocomment|n!',
+        'numbering|N!',
         'output|o=s',
         'placeholder|p=s',
+        'redshift|r!',
         'separator|S=s',
         'spaces|s=i',
         'format-type|t!',
@@ -314,6 +320,8 @@ sub get_command_line_args {
     $cfg{ 'wrap-limit' }    //= 0;
     $cfg{ 'wrap-after' }    //= 0;
     $cfg{ 'space' }         //= ' ';
+    $cfg{ 'numbering' }     //= 0;
+    $cfg{ 'redshift' }      //= 0;
 
     if ($cfg{ 'tabs' }) {
         $cfg{ 'spaces' } = 1;
