@@ -299,8 +299,8 @@ WHERE
 --
 
 CREATE FUNCTION fn_opf12 (int4, int2)
-    RETURNS BIGINT
-    AS 'SELECT NULL::BIGINT;'
+    RETURNS bigint
+    AS 'SELECT NULL::bigint;'
     LANGUAGE SQL;
 
 ALTER OPERATOR FAMILY alt_opf12
@@ -317,8 +317,8 @@ BEGIN TRANSACTION;
 CREATE OPERATOR FAMILY alt_opf13
     USING HASH;
 CREATE FUNCTION fn_opf13 (int4)
-    RETURNS BIGINT
-    AS 'SELECT NULL::BIGINT;'
+    RETURNS bigint
+    AS 'SELECT NULL::bigint;'
     LANGUAGE SQL;
 ALTER OPERATOR FAMILY alt_opf13
     USING HASH
@@ -332,8 +332,8 @@ BEGIN TRANSACTION;
 CREATE OPERATOR FAMILY alt_opf14
     USING btree;
 CREATE FUNCTION fn_opf14 (int4)
-    RETURNS BIGINT
-    AS 'SELECT NULL::BIGINT;'
+    RETURNS bigint
+    AS 'SELECT NULL::bigint;'
     LANGUAGE SQL;
 ALTER OPERATOR FAMILY alt_opf14
     USING btree
@@ -347,8 +347,8 @@ BEGIN TRANSACTION;
 CREATE OPERATOR FAMILY alt_opf15
     USING HASH;
 CREATE FUNCTION fn_opf15 (int4, int2)
-    RETURNS BIGINT
-    AS 'SELECT NULL::BIGINT;'
+    RETURNS bigint
+    AS 'SELECT NULL::bigint;'
     LANGUAGE SQL;
 ALTER OPERATOR FAMILY alt_opf15
     USING HASH
