@@ -1098,8 +1098,7 @@ SELECT
 SELECT
     - 1 != ALL (ARRAY (
             SELECT
-                NULLIF (g.i,
-                    900)
+                NULLIF (g.i, 900)
             FROM
                 generate_series(1, 1000) g (i)));
 
@@ -1258,9 +1257,9 @@ SELECT
 
 SELECT
     '{
-               0 second,
-               @ 1 hour @ 42 minutes @ 20 seconds
-             }'::interval[];
+           0 second,
+           @ 1 hour @ 42 minutes @ 20 seconds
+         }'::interval[];
 
 SELECT
     ARRAY[]::text[];
@@ -1274,7 +1273,7 @@ SELECT
 CREATE TEMP TABLE arraggtest (
     f1 int[],
     f2 text[][],
-    f3 FLOAT[]
+    f3 float[]
 );
 
 INSERT INTO arraggtest (f1, f2, f3)
