@@ -974,8 +974,7 @@ END
 $$;
 
 SELECT
-    mylt2 ('a',
-        'B' COLLATE "en-x-icu") AS t,
+    mylt2 ('a', 'B' COLLATE "en-x-icu") AS t,
     mylt2 ('a', 'B' COLLATE "C") AS f;
 
 CREATE OR REPLACE FUNCTION mylt2 (x text, y text)
@@ -991,17 +990,14 @@ END
 $$;
 
 SELECT
-    mylt2 ('a',
-        'B') AS f;
+    mylt2 ('a', 'B') AS f;
 
 SELECT
-    mylt2 ('a',
-        'B' COLLATE "C") AS fail;
+    mylt2 ('a', 'B' COLLATE "C") AS fail;
 
 -- conflicting collations
 SELECT
-    mylt2 ('a',
-        'B' COLLATE "POSIX") AS f;
+    mylt2 ('a', 'B' COLLATE "POSIX") AS f;
 
 -- polymorphism
 SELECT
@@ -1244,12 +1240,10 @@ CREATE TYPE textrange_en_us AS RANGE (
 );
 
 SELECT
-    textrange_c ('A',
-        'Z') @> 'b'::text;
+    textrange_c ('A', 'Z') @> 'b'::text;
 
 SELECT
-    textrange_en_us ('A',
-        'Z') @> 'b'::text;
+    textrange_en_us ('A', 'Z') @> 'b'::text;
 
 DROP TYPE textrange_c;
 
