@@ -1957,11 +1957,7 @@ SELECT
     *
 FROM
     tenk1
-WHERE (thousand, tenthous)
-IN ((1,
-        1001),
-    (NULL,
-        NULL));
+WHERE (thousand, tenthous) IN ((1, 1001), (NULL, NULL));
 
 --
 -- Check matching of boolean index columns to WHERE conditions and sort keys
@@ -2059,8 +2055,7 @@ CREATE TABLE reindex_verbose (
     id integer PRIMARY KEY
 );
 
-\set VERBOSITY terse 
--- suppress machine-dependent details
+\set VERBOSITY terse \\ -- suppress machine-dependent details
 REINDEX (VERBOSE)
 TABLE reindex_verbose;
 
