@@ -31,10 +31,10 @@ CREATE DOMAIN domaintext text;
 
 -- Test explicit coercions --- these should succeed (and truncate)
 SELECT
-    cast('123456' AS domainvarchar);
+    CAST('123456' AS domainvarchar);
 
 SELECT
-    cast('12345' AS domainvarchar);
+    CAST('12345' AS domainvarchar);
 
 -- Test tables using domains
 CREATE TABLE basictest (
@@ -662,18 +662,18 @@ FROM
 
 -- Test out coerced (casted) constraints
 SELECT
-    cast('1' AS dnotnull);
+    CAST('1' AS dnotnull);
 
 SELECT
-    cast(NULL AS dnotnull);
+    CAST(NULL AS dnotnull);
 
 -- fail
 SELECT
-    cast(cast(NULL AS dnull) AS dnotnull);
+    CAST(CAST(NULL AS dnull) AS dnotnull);
 
 -- fail
 SELECT
-    cast(col4 AS dnotnull)
+    CAST(col4 AS dnotnull)
 FROM
     nulltest;
 
@@ -862,7 +862,7 @@ ALTER DOMAIN con
     DROP CONSTRAINT IF EXISTS nonexistent;
 
 -- Test ALTER DOMAIN .. CONSTRAINT .. NOT VALID
-CREATE DOMAIN things AS INT;
+CREATE DOMAIN things AS int;
 
 CREATE TABLE thethings (
     stuff things
@@ -895,7 +895,7 @@ CREATE DOMAIN dom AS integer;
 
 CREATE VIEW domview AS
 SELECT
-    cast(col1 AS dom)
+    CAST(col1 AS dom)
 FROM
     domtab;
 
@@ -1452,8 +1452,7 @@ CREATE FUNCTION sql_is_distinct_from (anyelement, anyelement)
     AS 'select $1 is distinct from $2 limit 1'
 ;
 
-CREATE DOMAIN inotnull int CHECK (sql_is_distinct_from (value,
-        NULL));
+CREATE DOMAIN inotnull int CHECK (sql_is_distinct_from (value, NULL));
 
 SELECT
     1::inotnull;
