@@ -529,12 +529,7 @@ SELECT
 SELECT
     x,
     sind (x),
-    sind (x)
-    IN (- 1,
-        - 0.5,
-        0,
-        0.5,
-        1) AS sind_exact
+    sind (x) IN (- 1, - 0.5, 0, 0.5, 1) AS sind_exact
 FROM (
     VALUES (0),
         (30),
@@ -549,12 +544,7 @@ FROM (
 SELECT
     x,
     cosd (x),
-    cosd (x)
-    IN (- 1,
-        - 0.5,
-        0,
-        0.5,
-        1) AS cosd_exact
+    cosd (x) IN (- 1, - 0.5, 0, 0.5, 1) AS cosd_exact
 FROM (
     VALUES (0),
         (60),
@@ -569,19 +559,9 @@ FROM (
 SELECT
     x,
     tand (x),
-    tand (x)
-    IN ('-Infinity'::float8,
-        - 1,
-        0,
-        1,
-        'Infinity'::float8) AS tand_exact,
+    tand (x) IN ('-Infinity'::float8, - 1, 0, 1, 'Infinity'::float8) AS tand_exact,
     cotd (x),
-    cotd (x)
-    IN ('-Infinity'::float8,
-        - 1,
-        0,
-        1,
-        'Infinity'::float8) AS cotd_exact
+    cotd (x) IN ('-Infinity'::float8, - 1, 0, 1, 'Infinity'::float8) AS cotd_exact
 FROM (
     VALUES (0),
         (45),
@@ -596,19 +576,9 @@ FROM (
 SELECT
     x,
     asind (x),
-    asind (x)
-    IN (- 90,
-        - 30,
-        0,
-        30,
-        90) AS asind_exact,
+    asind (x) IN (- 90, - 30, 0, 30, 90) AS asind_exact,
     acosd (x),
-    acosd (x)
-    IN (0,
-        60,
-        90,
-        120,
-        180) AS acosd_exact
+    acosd (x) IN (0, 60, 90, 120, 180) AS acosd_exact
 FROM (
     VALUES (- 1),
         (- 0.5),
@@ -619,12 +589,7 @@ FROM (
 SELECT
     x,
     atand (x),
-    atand (x)
-    IN (- 90,
-        - 45,
-        0,
-        45,
-        90) AS atand_exact
+    atand (x) IN (- 90, - 45, 0, 45, 90) AS atand_exact
 FROM (
     VALUES ('-Infinity'::float8),
         (- 1),
@@ -636,11 +601,7 @@ SELECT
     x,
     y,
     atan2d (y, x),
-    atan2d (y, x)
-    IN (- 90,
-        0,
-        90,
-        180) AS atan2d_exact
+    atan2d (y, x) IN (- 90, 0, 90, 180) AS atan2d_exact
 FROM (
     SELECT
         10 * cosd (a),
@@ -673,13 +634,13 @@ CREATE TYPE xfloat8 (
     LIKE = float8
 );
 
-CREATE cast( xfloat8 AS float8) without FUNCTION;
+CREATE CAST( xfloat8 AS float8) WITHOUT FUNCTION;
 
-CREATE cast( float8 AS xfloat8) without FUNCTION;
+CREATE CAST( float8 AS xfloat8) WITHOUT FUNCTION;
 
-CREATE cast( xfloat8 AS bigint) without FUNCTION;
+CREATE CAST( xfloat8 AS bigint) WITHOUT FUNCTION;
 
-CREATE cast( bigint AS xfloat8) without FUNCTION;
+CREATE CAST( bigint AS xfloat8) WITHOUT FUNCTION;
 
 -- float8: seeeeeee eeeeeeee eeeeeeee mmmmmmmm mmmmmmmm(x4)
 -- we don't care to assume the platform's strtod() handles subnormals
