@@ -1574,8 +1574,7 @@ IMPORT FOREIGN SCHEMA s1
 EXCEPT (t1,
     t2)
 FROM
-    SERVER s9 INTO public OPTIONS (option1 'value1',
-        option2 'value2');
+    SERVER s9 INTO public OPTIONS (option1 'value1', option2 'value2');
 
 -- ERROR
 -- DROP FOREIGN TABLE
