@@ -163,16 +163,22 @@ CREATE TABLE inserttest2 (
     f2 text
 );
 
-CREATE RULE irule1 AS ON INSERT TO inserttest2 DO also INSERT INTO inserttest (f3.if2[1], f3.if2[2])
-VALUES (new.f1, new.f2);
+CREATE RULE irule1 AS ON INSERT TO inserttest2
+    DO ALSO
+    INSERT INTO inserttest (f3.if2[1], f3.if2[2])
+    VALUES (new.f1, new.f2);
 
-CREATE RULE irule2 AS ON INSERT TO inserttest2 DO also INSERT INTO inserttest (f4[1].if1, f4[1].if2[2])
-VALUES (1, 'fool'), (new.f1, new.f2);
+CREATE RULE irule2 AS ON INSERT TO inserttest2
+    DO ALSO
+    INSERT INTO inserttest (f4[1].if1, f4[1].if2[2])
+    VALUES (1, 'fool'), (new.f1, new.f2);
 
-CREATE RULE irule3 AS ON INSERT TO inserttest2 DO also INSERT INTO inserttest (f4[1].if1, f4[1].if2[2])
-SELECT
-    new.f1,
-    new.f2;
+CREATE RULE irule3 AS ON INSERT TO inserttest2
+    DO ALSO
+    INSERT INTO inserttest (f4[1].if1, f4[1].if2[2])
+    SELECT
+        new.f1,
+        new.f2;
 
 \d+ inserttest2
 DROP TABLE inserttest2;
@@ -829,7 +835,7 @@ CREATE FUNCTION mlparted5abrtrig_func ()
     RETURNS TRIGGER
     AS $$
 BEGIN
-    new.c = 'b';
+    NEW.c = 'b';
     RETURN new;
 END;
 $$
@@ -1177,7 +1183,7 @@ CREATE OR REPLACE FUNCTION brtrigpartcon1trigf ()
     RETURNS TRIGGER
     AS $$
 BEGIN
-    new.a := 2;
+    NEW.a := 2;
     RETURN new;
 END
 $$
@@ -1266,7 +1272,7 @@ CREATE OR REPLACE FUNCTION donothingbrtrig_func ()
     RETURNS TRIGGER
     AS $$
 BEGIN
-    RAISE notice 'b: %', new.b;
+    RAISE notice 'b: %', NEW.b;
     RETURN NULL;
 END
 $$
