@@ -1958,8 +1958,7 @@ WHERE
         SELECT
             1 FROM int8_tbl t3
         WHERE
-            ss.y IS NOT NULL
-        LIMIT 1)
+            ss.y IS NOT NULL LIMIT 1)
 ORDER BY
     1,
     2;
@@ -1979,8 +1978,7 @@ WHERE
         SELECT
             1 FROM int8_tbl t3
         WHERE
-            ss.y IS NOT NULL
-        LIMIT 1)
+            ss.y IS NOT NULL LIMIT 1)
 ORDER BY
     1,
     2;
@@ -4123,7 +4121,8 @@ FROM
                 q1 < f1) ss1 ON a.q2 = ss1.q1
         CROSS JOIN LATERAL (
             SELECT
-                q1, coalesce(ss1.x, q2) AS y
+                q1,
+                coalesce(ss1.x, q2) AS y
             FROM
                 int8_tbl d) ss2) ON c.q2 = ss2.q1,
     LATERAL (
