@@ -4,7 +4,7 @@ SELECT
 
 -- OK.
 SELECT
-    $$ '' $$::json;
+    $$ ''$$::json;
 
 -- ERROR, single quotes are not allowed
 SELECT
@@ -17,7 +17,7 @@ SELECT
 -- ERROR, quotes not closed
 SELECT
     '"abc
-    def"'::json;
+def"'::json;
 
 -- ERROR, unescaped newline in string constant
 SELECT
@@ -336,9 +336,7 @@ FROM (
         generate_series(4, 5) y) q;
 
 SELECT
-    json_agg(q
-    ORDER BY
-        x, y)
+    json_agg(q ORDER BY x, y)
 FROM
     ROWS q;
 
@@ -350,9 +348,7 @@ WHERE
     x = 1;
 
 SELECT
-    json_agg(q
-    ORDER BY
-        x NULLS FIRST, y)
+    json_agg(q ORDER BY x NULLS FIRST, y)
 FROM
     ROWS q;
 
@@ -1446,10 +1442,10 @@ CREATE TEMP TABLE jspoptest (
 INSERT INTO jspoptest
 SELECT
     '{
-    	"jsa": [1, "2", null, 4],
-    	"rec": {"a": "abc", "c": "01.02.2003", "x": 43.2},
-    	"reca": [{"a": "abc", "b": 456}, null, {"c": "01.02.2003", "x": 43.2}]
-    }'::json
+	"jsa": [1, "2", null, 4],
+	"rec": {"a": "abc", "c": "01.02.2003", "x": 43.2},
+	"reca": [{"a": "abc", "b": 456}, null, {"c": "01.02.2003", "x": 43.2}]
+}'::json
 FROM
     generate_series(1, 3);
 
@@ -1841,64 +1837,40 @@ SELECT
 
 -- json_to_tsvector
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '"all"');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '"all"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '"key"');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '"key"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '"string"');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '"string"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '"numeric"');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '"numeric"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '"boolean"');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '"boolean"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '["string", "numeric"]');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '["string", "numeric"]');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '"all"');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '"all"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '"key"');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '"key"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '"string"');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '"string"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '"numeric"');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '"numeric"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '"boolean"');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '"boolean"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '["string", "numeric"]');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '["string", "numeric"]');
 
 -- to_tsvector corner cases
 SELECT
@@ -1915,45 +1887,31 @@ SELECT
 
 -- json_to_tsvector corner cases
 SELECT
-    json_to_tsvector ('""'::json,
-        '"all"');
+    json_to_tsvector('""'::json, '"all"');
 
 SELECT
-    json_to_tsvector ('{}'::json,
-        '"all"');
+    json_to_tsvector('{}'::json, '"all"');
 
 SELECT
-    json_to_tsvector ('[]'::json,
-        '"all"');
+    json_to_tsvector('[]'::json, '"all"');
 
 SELECT
-    json_to_tsvector ('null'::json,
-        '"all"');
+    json_to_tsvector('null'::json, '"all"');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '""');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '""');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '{}');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '{}');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '[]');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '[]');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        'null');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, 'null');
 
 SELECT
-    json_to_tsvector ('english',
-        '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json,
-        '["all", null]');
+    json_to_tsvector('english', '{"a": "aaa in bbb", "b": 123, "c": 456, "d": true, "f": false, "g": null}'::json, '["all", null]');
 
 -- ts_headline for json
 SELECT
