@@ -499,8 +499,7 @@ WHERE
     AND abs(y.a) << < 5;
 
 -- clean up (regress_priv_user1's objects are all dropped later)
-DROP FUNCTION leak2 (integer, integer)
-CASCADE;
+DROP FUNCTION leak2 (integer, integer) CASCADE;
 
 -- groups
 SET SESSION AUTHORIZATION regress_priv_user3;
@@ -1485,8 +1484,7 @@ CREATE CAST( priv_testdomain1 AS priv_testdomain3a
 )
 WITH FUNCTION castfunc (int);
 
-DROP FUNCTION castfunc (int)
-CASCADE;
+DROP FUNCTION castfunc (int) CASCADE;
 
 DROP DOMAIN priv_testdomain3a;
 
@@ -1675,8 +1673,7 @@ DROP TYPE test8b;
 
 DROP CAST(priv_testdomain1 AS priv_testdomain3b);
 
-DROP FUNCTION castfunc (int)
-CASCADE;
+DROP FUNCTION castfunc (int) CASCADE;
 
 DROP DOMAIN priv_testdomain3b;
 
@@ -2253,7 +2250,7 @@ SELECT
     lo_create(2002);
 
 SELECT
-    loread(lo_open(1001, x '20000'::int), 32);
+    loread (lo_open(1001, x '20000'::int), 32);
 
 -- allowed, for now
 SELECT
@@ -2261,17 +2258,17 @@ SELECT
 
 -- fail, wrong mode
 SELECT
-    loread(lo_open(1001, x '40000'::int), 32);
+    loread (lo_open(1001, x '40000'::int), 32);
 
 SELECT
-    loread(lo_open(1002, x '40000'::int), 32);
+    loread (lo_open(1002, x '40000'::int), 32);
 
 -- to be denied
 SELECT
-    loread(lo_open(1003, x '40000'::int), 32);
+    loread (lo_open(1003, x '40000'::int), 32);
 
 SELECT
-    loread(lo_open(1004, x '40000'::int), 32);
+    loread (lo_open(1004, x '40000'::int), 32);
 
 SELECT
     lowrite(lo_open(1001, x '20000'::int), 'abcd');
@@ -2320,14 +2317,14 @@ ORDER BY
 SET SESSION AUTHORIZATION regress_priv_user3;
 
 SELECT
-    loread(lo_open(1001, x '40000'::int), 32);
+    loread (lo_open(1001, x '40000'::int), 32);
 
 SELECT
-    loread(lo_open(1003, x '40000'::int), 32);
+    loread (lo_open(1003, x '40000'::int), 32);
 
 -- to be denied
 SELECT
-    loread(lo_open(1005, x '40000'::int), 32);
+    loread (lo_open(1005, x '40000'::int), 32);
 
 SELECT
     lo_truncate(lo_open(1005, x '20000'::int), 10);
@@ -2344,7 +2341,7 @@ SET lo_compat_privileges = FALSE;
 SET SESSION AUTHORIZATION regress_priv_user4;
 
 SELECT
-    loread(lo_open(1002, x '40000'::int), 32);
+    loread (lo_open(1002, x '40000'::int), 32);
 
 -- to be denied
 SELECT
@@ -2356,9 +2353,7 @@ SELECT
 
 -- to be denied
 SELECT
-    lo_put (1002,
-        1,
-        'abcd');
+    lo_put(1002, 1, 'abcd');
 
 -- to be denied
 SELECT
@@ -2384,7 +2379,7 @@ SET lo_compat_privileges = TRUE;
 SET SESSION AUTHORIZATION regress_priv_user4;
 
 SELECT
-    loread(lo_open(1002, x '40000'::int), 32);
+    loread (lo_open(1002, x '40000'::int), 32);
 
 SELECT
     lowrite(lo_open(1002, x '20000'::int), 'abcd');
