@@ -259,19 +259,11 @@ SELECT
 
 SELECT
     ROW (1,
-        2)
-    IN (ROW (3,
-            4),
-        ROW (1,
-            2));
+        2) IN (ROW (3, 4), ROW (1, 2));
 
 SELECT
     ROW (1,
-        2)
-    IN (ROW (3,
-            4),
-        ROW (1,
-            2::int8));
+        2) IN (ROW (3, 4), ROW (1, 2::int8));
 
 -- Check row comparison with a subselect
 SELECT
@@ -300,8 +292,7 @@ SELECT
     tenthous
 FROM
     tenk1
-WHERE (thousand, tenthous) >= (997,
-    5000)
+WHERE (thousand, tenthous) >= (997, 5000)
 ORDER BY
     thousand,
     tenthous;
@@ -311,8 +302,7 @@ SELECT
     tenthous
 FROM
     tenk1
-WHERE (thousand, tenthous) >= (997,
-    5000)
+WHERE (thousand, tenthous) >= (997, 5000)
 ORDER BY
     thousand,
     tenthous;
@@ -326,9 +316,7 @@ SELECT
     four
 FROM
     tenk1
-WHERE (thousand, tenthous, four) > (998,
-    5000,
-    3)
+WHERE (thousand, tenthous, four) > (998, 5000, 3)
 ORDER BY
     thousand,
     tenthous;
@@ -339,9 +327,7 @@ SELECT
     four
 FROM
     tenk1
-WHERE (thousand, tenthous, four) > (998,
-    5000,
-    3)
+WHERE (thousand, tenthous, four) > (998, 5000, 3)
 ORDER BY
     thousand,
     tenthous;
@@ -354,8 +340,7 @@ SELECT
     tenthous
 FROM
     tenk1
-WHERE (998, 5000) < (thousand,
-    tenthous)
+WHERE (998, 5000) < (thousand, tenthous)
 ORDER BY
     thousand,
     tenthous;
@@ -365,8 +350,7 @@ SELECT
     tenthous
 FROM
     tenk1
-WHERE (998, 5000) < (thousand,
-    tenthous)
+WHERE (998, 5000) < (thousand, tenthous)
 ORDER BY
     thousand,
     tenthous;
@@ -379,8 +363,7 @@ SELECT
     hundred
 FROM
     tenk1
-WHERE (998, 5000) < (thousand,
-    hundred)
+WHERE (998, 5000) < (thousand, hundred)
 ORDER BY
     thousand,
     hundred;
@@ -390,8 +373,7 @@ SELECT
     hundred
 FROM
     tenk1
-WHERE (998, 5000) < (thousand,
-    hundred)
+WHERE (998, 5000) < (thousand, hundred)
 ORDER BY
     thousand,
     hundred;
@@ -427,8 +409,7 @@ SELECT
     b
 FROM
     test_table
-WHERE (a, b) > ('a',
-    'a')
+WHERE (a, b) > ('a', 'a')
 ORDER BY
     a,
     b;
@@ -438,8 +419,7 @@ SELECT
     b
 FROM
     test_table
-WHERE (a, b) > ('a',
-    'a')
+WHERE (a, b) > ('a', 'a')
 ORDER BY
     a,
     b;
@@ -944,16 +924,13 @@ $$
 LANGUAGE sql;
 
 SELECT
-    fcompos1 (ROW (1,
-            'one'));
+    fcompos1 (ROW (1, 'one'));
 
 SELECT
-    fcompos2 (ROW (2,
-            'two'));
+    fcompos2 (ROW (2, 'two'));
 
 SELECT
-    fcompos3 (ROW (3,
-            'three'));
+    fcompos3 (ROW (3, 'three'));
 
 SELECT
     *
@@ -967,7 +944,7 @@ FROM
 --
 
 SELECT
-    cast(fullname AS text)
+    CAST(fullname AS text)
 FROM
     fullname;
 
@@ -991,7 +968,7 @@ FROM
 -- same, but RECORD instead of named composite type:
 
 SELECT
-    cast(ROW ('Jim', 'Beam') AS text);
+    CAST(ROW ('Jim', 'Beam') AS text);
 
 SELECT
     (ROW ('Jim',
