@@ -226,8 +226,7 @@ SELECT
     f1 AS "Correlated Field"
 FROM
     SUBSELECT_TBL
-WHERE (f1, f2)
-IN (
+WHERE (f1, f2) IN (
     SELECT
         f2,
         CAST(f3 AS int4)
@@ -673,7 +672,7 @@ DROP TABLE orderstest CASCADE;
 
 CREATE temp TABLE parts (
     partnum text,
-    COST float8
+    cost float8
 );
 
 CREATE temp TABLE shipped (
@@ -1048,7 +1047,8 @@ FROM (
             FROM
                 int4_tbl
             WHERE
-                f1 = q2) AS sq1, 42 AS dummy
+                f1 = q2) AS sq1,
+            42 AS dummy
         FROM
             int8_tbl) sq0
     JOIN int4_tbl i4 ON dummy = i4.f1;
@@ -1375,8 +1375,7 @@ WHERE (
         f1
     ELSE
         NULL
-    END)
-    IN (
+    END) IN (
         SELECT
             ten
         FROM
@@ -1395,8 +1394,7 @@ WHERE (
         f1
     ELSE
         NULL
-    END)
-    IN (
+    END) IN (
         SELECT
             ten
         FROM
@@ -1414,8 +1412,7 @@ SELECT
     *
 FROM
     int4_tbl o
-WHERE (f1, f1)
-IN (
+WHERE (f1, f1) IN (
     SELECT
         f1,
         generate_series(1, 50) / 10 g
@@ -1428,8 +1425,7 @@ SELECT
     *
 FROM
     int4_tbl o
-WHERE (f1, f1)
-IN (
+WHERE (f1, f1) IN (
     SELECT
         f1,
         generate_series(1, 50) / 10 g
@@ -1825,13 +1821,13 @@ AS ((
             FROM
                 x
 )
-        SELECT
-            z.a || z1.a AS a
-        FROM
-            z
-        CROSS JOIN z AS z1
-    WHERE
-        length(z.a || z1.a) < 5))
+            SELECT
+                z.a || z1.a AS a
+            FROM
+                z
+            CROSS JOIN z AS z1
+        WHERE
+            length(z.a || z1.a) < 5))
 SELECT
     *
 FROM
@@ -1876,12 +1872,12 @@ AS ((
             FROM
                 x
 )
-        SELECT
-            z.a || z.a AS a
-        FROM
-            z
-        WHERE
-            length(z.a || z.a) < 5))
+            SELECT
+                z.a || z.a AS a
+            FROM
+                z
+            WHERE
+                length(z.a || z.a) < 5))
 SELECT
     *
 FROM
@@ -1930,10 +1926,10 @@ FROM ( WITH y AS (
         FROM
             x
 )
-    SELECT
-        *
-    FROM
-        y) ss;
+        SELECT
+            *
+        FROM
+            y) ss;
 
 EXPLAIN (
     VERBOSE,
@@ -1952,10 +1948,10 @@ FROM ( WITH y AS (
         FROM
             x
 )
-    SELECT
-        *
-    FROM
-        y) ss;
+        SELECT
+            *
+        FROM
+            y) ss;
 
 -- Ensure that we inline the currect CTE when there are
 -- multiple CTEs with the same name
@@ -1973,10 +1969,10 @@ FROM ( WITH x AS (
         SELECT
             2 AS y
 )
-    SELECT
-        *
-    FROM
-        x) ss;
+        SELECT
+            *
+        FROM
+            x) ss;
 
 -- Row marks are not pushed into CTEs
 EXPLAIN (
