@@ -2056,8 +2056,7 @@ SELECT
     events & 8 != 0 AS ins,
     events & 16 != 0 AS del
 FROM
-    pg_catalog.pg_relation_is_updatable ('rw_view3'::regclass,
-        FALSE) t (events);
+    pg_catalog.pg_relation_is_updatable ('rw_view3'::regclass, FALSE) t (events);
 
 DROP TABLE base_tbl CASCADE;
 
@@ -2529,17 +2528,14 @@ WHERE
     a = 1;
 
 -- should fail
-PREPARE ins (int,
-    int[]) AS
+PREPARE ins (int, int[]) AS
 INSERT INTO rw_view1
     VALUES ($1, $2);
 
-EXECUTE ins (2,
-    ARRAY[1, 2, 3]);
+EXECUTE ins (2, ARRAY[1, 2, 3]);
 
 -- ok
-EXECUTE ins (10,
-    ARRAY[4, 5]);
+EXECUTE ins (10, ARRAY[4, 5]);
 
 -- should fail
 DEALLOCATE PREPARE ins;
@@ -3062,20 +3058,20 @@ CREATE RULE base_tbl_ins_rule AS ON INSERT TO base_tbl WHERE
         SELECT
             1 FROM
             base_tbl t WHERE
-            t.id = new.id)
+            t.id = NEW.id)
         DO INSTEAD
         UPDATE
             base_tbl SET
-            data = new.data,
+            data = NEW.data,
             deleted = FALSE WHERE
-            id = new.id;
+            id = NEW.id;
 
 CREATE RULE base_tbl_del_rule AS ON DELETE TO base_tbl
     DO INSTEAD
     UPDATE
         base_tbl SET
         deleted = TRUE WHERE
-        id = old.id;
+        id = OLD.id;
 
 CREATE VIEW rw_view1 WITH ( security_barrier = TRUE
 ) AS
@@ -3655,18 +3651,13 @@ SELECT
     events & 8 != 0 AS ins,
     events & 16 != 0 AS del
 FROM
-    pg_catalog.pg_relation_is_updatable ('uv_pt'::regclass,
-        FALSE) t (events);
+    pg_catalog.pg_relation_is_updatable ('uv_pt'::regclass, FALSE) t (events);
 
 SELECT
-    pg_catalog.pg_column_is_updatable ('uv_pt'::regclass,
-        1::smallint,
-        FALSE);
+    pg_catalog.pg_column_is_updatable ('uv_pt'::regclass, 1::smallint, FALSE);
 
 SELECT
-    pg_catalog.pg_column_is_updatable ('uv_pt'::regclass,
-        2::smallint,
-        FALSE);
+    pg_catalog.pg_column_is_updatable ('uv_pt'::regclass, 2::smallint, FALSE);
 
 SELECT
     table_name,
@@ -3832,7 +3823,7 @@ INSERT INTO uv_iocu_view (a, b)
     VALUES ('xyxyxy', 3)
 ON CONFLICT (a)
     DO UPDATE SET
-        b = cast(excluded.two AS float);
+        b = CAST(excluded.two AS float);
 
 SELECT
     *
@@ -4205,7 +4196,7 @@ CREATE FUNCTION base_tab_def_view_instrig_func ()
     AS $$
 BEGIN
     INSERT INTO base_tab_def
-        VALUES (new.a, new.b, new.c, new.d, new.e);
+        VALUES (NEW.a, NEW.b, NEW.c, NEW.d, NEW.e);
     RETURN new;
 END;
 $$
@@ -4260,7 +4251,7 @@ DROP FUNCTION base_tab_def_view_instrig_func;
 
 CREATE RULE base_tab_def_view_ins_rule AS ON INSERT TO base_tab_def_view
     DO INSTEAD
-    INSERT INTO base_tab_def VALUES (new.a, new.b, new.c, new.d, new.e);
+    INSERT INTO base_tab_def VALUES (NEW.a, NEW.b, NEW.c, NEW.d, NEW.e);
 
 TRUNCATE base_tab_def;
 
@@ -4306,7 +4297,9 @@ ORDER BY
 
 DROP RULE base_tab_def_view_ins_rule ON base_tab_def_view;
 
-CREATE RULE base_tab_def_view_ins_rule AS ON INSERT TO base_tab_def_view DO also INSERT INTO base_tab_def VALUES (new.a, new.b, new.c, new.d, new.e);
+CREATE RULE base_tab_def_view_ins_rule AS ON INSERT TO base_tab_def_view
+    DO ALSO
+    INSERT INTO base_tab_def VALUES (NEW.a, NEW.b, NEW.c, NEW.d, NEW.e);
 
 TRUNCATE base_tab_def;
 
